@@ -112,18 +112,18 @@ case $os in
 esac
 
 # bash will eat your spaces, so let's array. see http://mywiki.wooledge.org/BashFAQ/050 for more fun.
-params=("--user" "puppetdb" "--group" "puppetdb" "--chdir" "$dir" "--realname" "puppetdb" "--operating-system" "$os" "--name" "puppetdb" "--package-version" "7.13.0" "--release" "1")
+params=("--user" "puppetdb" "--group" "puppetdb" "--chdir" "$dir" "--realname" "puppetdb" "--operating-system" "$os" "--name" "puppetdb" "--package-version" "8.5.0" "--release" "1" "--platform-version" "8")
 if [ -n "$os_version" ]; then params+=("--os-version" "$os_version"); fi
 if [ -n "$os_dist" ]; then params+=("--dist" "$os_dist"); fi
 
-params+=('--description' "$(printf "Puppet Labs puppetdb\nContains: Puppet-integrated catalog and fact storage (puppetlabs/puppetdb 7.13.0,org.bouncycastle/bcpkix-jdk18on 1.71,org.clojure/clojure 1.11.1,com.zaxxer/HikariCP 2.7.4,puppetlabs/puppetdb 7.13.0)")")
+params+=('--description' "$(printf "Puppet Labs puppetdb\nContains: Puppet-integrated catalog and fact storage (puppetlabs/puppetdb 8.5.0,org.bouncycastle/bcpkix-jdk18on 1.74,org.clojure/clojure 1.11.2,puppetlabs/puppetdb 8.5.0)")")
 
 DESTDIR="$basepath/termini" bash install.sh termini
 params+=('--build-termini')
 params+=('--termini-chdir' "$basepath/termini")
 termini_description='Termini for puppetdb\nContains terminus for:'
 
-termini_description+='puppetdb (version 7.13.0)'
+termini_description+='puppetdb (version 8.5.0)'
 
 params+=('--termini-description' "$(printf "$termini_description")")
 
