@@ -34,6 +34,7 @@ dest_apps_dir="${DESTDIR}${app_prefix}"
 app_data=${app_data:=/opt/puppetlabs/server/data/${real_name}}
 app_logdir=${app_logdir:=/var/log/puppetlabs/${real_name}}
 system_config_dir=${system_config_dir:=${app_prefix}/config}
+needrestart_confdir=${needrestart_dir:=/etc/needrestart/conf.d}
 
 
 ##################
@@ -142,8 +143,8 @@ function task_install_docs_deb {
 # install docs for rpm based systems
 function task_install_docs_rpm {
   if [ -d ext/docs ]; then
-    install -d "${DESTDIR}${app_prefix}/share/doc/puppetdb-7.13.0"
-    cp -a ext/docs "${DESTDIR}${app_prefix}/share/doc/puppetdb-7.13.0"
+    install -d "${DESTDIR}${app_prefix}/share/doc/puppetdb-8.5.0"
+    cp -a ext/docs "${DESTDIR}${app_prefix}/share/doc/puppetdb-8.5.0"
   fi
 }
 
@@ -159,13 +160,13 @@ function task_install {
 
   
 
-    install -m 0644 ext/config/conf.d/database.ini "${DESTDIR}${projconfdir}/conf.d/database.ini"
-    install -m 0644 ext/config/conf.d/auth.conf "${DESTDIR}${projconfdir}/conf.d/auth.conf"
-    install -m 0644 ext/config/conf.d/config.ini "${DESTDIR}${projconfdir}/conf.d/config.ini"
-    install -m 0644 ext/config/conf.d/repl.ini "${DESTDIR}${projconfdir}/conf.d/repl.ini"
-    install -m 0644 ext/config/conf.d/jetty.ini "${DESTDIR}${projconfdir}/conf.d/jetty.ini"
     install -m 0644 ext/config/bootstrap.cfg "${DESTDIR}${projconfdir}/bootstrap.cfg"
     install -m 0644 ext/config/logback.xml "${DESTDIR}${projconfdir}/logback.xml"
+    install -m 0644 ext/config/conf.d/config.ini "${DESTDIR}${projconfdir}/conf.d/config.ini"
+    install -m 0644 ext/config/conf.d/jetty.ini "${DESTDIR}${projconfdir}/conf.d/jetty.ini"
+    install -m 0644 ext/config/conf.d/database.ini "${DESTDIR}${projconfdir}/conf.d/database.ini"
+    install -m 0644 ext/config/conf.d/repl.ini "${DESTDIR}${projconfdir}/conf.d/repl.ini"
+    install -m 0644 ext/config/conf.d/auth.conf "${DESTDIR}${projconfdir}/conf.d/auth.conf"
     install -m 0644 ext/config/request-logging.xml "${DESTDIR}${projconfdir}/request-logging.xml"
 
     install -d -m 0755 "${dest_apps_dir}/scripts"
@@ -179,15 +180,15 @@ function task_install {
     ln -s "../apps/${real_name}/bin/${real_name}" "${DESTDIR}${symbindir}/${real_name}"
     install -d -m 0755 "${DESTDIR}${uxbindir}"
     ln -s "../server/apps/${real_name}/bin/${real_name}" "${DESTDIR}${uxbindir}/${real_name}"
-    install -m 0755 ext/cli/stop "${dest_apps_dir}/cli/apps/stop"
-    install -m 0755 ext/cli/anonymize "${dest_apps_dir}/cli/apps/anonymize"
-    install -m 0755 ext/cli/foreground "${dest_apps_dir}/cli/apps/foreground"
-    install -m 0755 ext/cli/upgrade "${dest_apps_dir}/cli/apps/upgrade"
-    install -m 0755 ext/cli/reload "${dest_apps_dir}/cli/apps/reload"
-    install -m 0755 ext/cli/config-migration "${dest_apps_dir}/cli/apps/config-migration"
     install -m 0755 ext/cli/delete-reports "${dest_apps_dir}/cli/apps/delete-reports"
     install -m 0755 ext/cli/start "${dest_apps_dir}/cli/apps/start"
+    install -m 0755 ext/cli/config-migration "${dest_apps_dir}/cli/apps/config-migration"
+    install -m 0755 ext/cli/reload "${dest_apps_dir}/cli/apps/reload"
+    install -m 0755 ext/cli/foreground "${dest_apps_dir}/cli/apps/foreground"
+    install -m 0755 ext/cli/stop "${dest_apps_dir}/cli/apps/stop"
+    install -m 0755 ext/cli/anonymize "${dest_apps_dir}/cli/apps/anonymize"
     install -m 0755 ext/cli/ssl-setup "${dest_apps_dir}/cli/apps/ssl-setup"
+    install -m 0755 ext/cli/upgrade "${dest_apps_dir}/cli/apps/upgrade"
 
 if [ -e "ext/cli_defaults/cli-defaults.sh" ]; then
     install -m 0755 ext/cli_defaults/cli-defaults.sh "${dest_apps_dir}/cli/"
@@ -216,22 +217,22 @@ function task_termini {
     # This also allows us to prefer PE ruby over system ruby, so this will work
     # with PE as well
     local rubylibdir=${rubylibdir:=/opt/puppetlabs/puppet/lib/ruby/vendor_ruby}
-    install -Dm 0644 puppet/functions/puppetdb_query.rb "${DESTDIR}${rubylibdir}/puppet/functions/puppetdb_query.rb"
+    install -Dm 0644 puppet/indirector/catalog/puppetdb.rb "${DESTDIR}${rubylibdir}/puppet/indirector/catalog/puppetdb.rb"
+    install -Dm 0644 puppet/indirector/facts/puppetdb_apply.rb "${DESTDIR}${rubylibdir}/puppet/indirector/facts/puppetdb_apply.rb"
+    install -Dm 0644 puppet/indirector/facts/puppetdb.rb "${DESTDIR}${rubylibdir}/puppet/indirector/facts/puppetdb.rb"
+    install -Dm 0644 puppet/indirector/node/puppetdb.rb "${DESTDIR}${rubylibdir}/puppet/indirector/node/puppetdb.rb"
+    install -Dm 0644 puppet/indirector/resource/puppetdb.rb "${DESTDIR}${rubylibdir}/puppet/indirector/resource/puppetdb.rb"
     install -Dm 0644 puppet/face/node/status.rb "${DESTDIR}${rubylibdir}/puppet/face/node/status.rb"
     install -Dm 0644 puppet/face/node/deactivate.rb "${DESTDIR}${rubylibdir}/puppet/face/node/deactivate.rb"
-    install -Dm 0644 puppet/indirector/catalog/puppetdb.rb "${DESTDIR}${rubylibdir}/puppet/indirector/catalog/puppetdb.rb"
-    install -Dm 0644 puppet/indirector/resource/puppetdb.rb "${DESTDIR}${rubylibdir}/puppet/indirector/resource/puppetdb.rb"
-    install -Dm 0644 puppet/indirector/facts/puppetdb.rb "${DESTDIR}${rubylibdir}/puppet/indirector/facts/puppetdb.rb"
-    install -Dm 0644 puppet/indirector/facts/puppetdb_apply.rb "${DESTDIR}${rubylibdir}/puppet/indirector/facts/puppetdb_apply.rb"
-    install -Dm 0644 puppet/indirector/node/puppetdb.rb "${DESTDIR}${rubylibdir}/puppet/indirector/node/puppetdb.rb"
-    install -Dm 0644 puppet/util/puppetdb.rb "${DESTDIR}${rubylibdir}/puppet/util/puppetdb.rb"
-    install -Dm 0644 puppet/util/puppetdb/command.rb "${DESTDIR}${rubylibdir}/puppet/util/puppetdb/command.rb"
+    install -Dm 0644 puppet/reports/puppetdb.rb "${DESTDIR}${rubylibdir}/puppet/reports/puppetdb.rb"
+    install -Dm 0644 puppet/functions/puppetdb_query.rb "${DESTDIR}${rubylibdir}/puppet/functions/puppetdb_query.rb"
+    install -Dm 0644 puppet/util/puppetdb/http.rb "${DESTDIR}${rubylibdir}/puppet/util/puppetdb/http.rb"
     install -Dm 0644 puppet/util/puppetdb/atom.rb "${DESTDIR}${rubylibdir}/puppet/util/puppetdb/atom.rb"
-    install -Dm 0644 puppet/util/puppetdb/command_names.rb "${DESTDIR}${rubylibdir}/puppet/util/puppetdb/command_names.rb"
     install -Dm 0644 puppet/util/puppetdb/config.rb "${DESTDIR}${rubylibdir}/puppet/util/puppetdb/config.rb"
     install -Dm 0644 puppet/util/puppetdb/char_encoding.rb "${DESTDIR}${rubylibdir}/puppet/util/puppetdb/char_encoding.rb"
-    install -Dm 0644 puppet/util/puppetdb/http.rb "${DESTDIR}${rubylibdir}/puppet/util/puppetdb/http.rb"
-    install -Dm 0644 puppet/reports/puppetdb.rb "${DESTDIR}${rubylibdir}/puppet/reports/puppetdb.rb"
+    install -Dm 0644 puppet/util/puppetdb/command.rb "${DESTDIR}${rubylibdir}/puppet/util/puppetdb/command.rb"
+    install -Dm 0644 puppet/util/puppetdb/command_names.rb "${DESTDIR}${rubylibdir}/puppet/util/puppetdb/command_names.rb"
+    install -Dm 0644 puppet/util/puppetdb.rb "${DESTDIR}${rubylibdir}/puppet/util/puppetdb.rb"
 }
 
 function task_defaults_redhat {
@@ -285,6 +286,8 @@ function task_systemd_deb {
     fi
     install -d -m 0755 "${DESTDIR}${tmpfilesdir}"
     install -m 0644 ext/puppetdb.tmpfiles.conf "${DESTDIR}${tmpfilesdir}/puppetdb.conf"
+    install -d -m 0755 "${DESTDIR}${needrestart_confdir}"
+    install -m 0644 ext/puppetdb.needrestart.conf "${DESTDIR}${needrestart_confdir}/puppetdb.conf"
 }
 
 function task_service_account {
