@@ -1,4 +1,4 @@
-(defproject puppetlabs/trapperkeeper "3.2.1"
+(defproject puppetlabs/trapperkeeper "4.0.0"
   :description "A framework for configuring, composing, and running Clojure services."
 
   :license {:name "Apache License, Version 2.0"
@@ -6,7 +6,7 @@
 
   :min-lein-version "2.9.0"
 
-  :parent-project {:coords [puppetlabs/clj-parent "4.6.17"]
+  :parent-project {:coords [puppetlabs/clj-parent "6.0.1"]
                    :inherit [:managed-dependencies]}
 
   ;; Abort when version ranges or version conflicts are detected in
@@ -18,6 +18,7 @@
                  [org.clojure/tools.macro]
                  [org.clojure/core.async]
 
+                 [org.slf4j/slf4j-api]
                  [org.slf4j/log4j-over-slf4j]
                  [ch.qos.logback/logback-classic]
                  ;; even though we don't strictly have a dependency on the following two
@@ -31,7 +32,6 @@
 
                  [clj-time]
                  [clj-commons/fs]
-                 [clj-commons/clj-yaml]
 
                  [prismatic/plumbing]
                  [prismatic/schema]
@@ -39,10 +39,12 @@
                  [beckon]
 
                  [puppetlabs/typesafe-config]
-                 [puppetlabs/kitchensink]
+                 ;; exclusion added due to dependency conflict over asm and jackson-dataformat-cbor
+                 ;; see https://github.com/puppetlabs/trapperkeeper/pull/306#issuecomment-1467059264
+                 [puppetlabs/kitchensink nil :exclusions [cheshire]]
                  [puppetlabs/i18n]
                  [nrepl/nrepl]
-                 ]
+                 [io.github.clj-kondo/config-slingshot-slingshot "1.0.0"]]
 
   :deploy-repositories [["releases" {:url "https://clojars.org/repo"
                                      :username :env/clojars_jenkins_username
@@ -61,14 +63,32 @@
   :profiles {:dev {:source-paths ["examples/shutdown_app/src"
                                   "examples/java_service/src/clj"]
                    :java-source-paths ["examples/java_service/src/java"]
-                   :dependencies [[puppetlabs/kitchensink :classifier "test"]]}
+                   :dependencies [[puppetlabs/kitchensink nil :classifier "test" :exclusions [cheshire]]]}
 
              :testutils {:source-paths ^:replace ["test"]}
              :uberjar {:aot [puppetlabs.trapperkeeper.main]
                        :classifiers ^:replace []}}
 
   :plugins [[lein-parent "0.3.7"]
-            [puppetlabs/i18n "0.8.0"]]
+            [jonase/eastwood "1.2.2" :exclusions [org.clojure/clojure]]
+            [puppetlabs/i18n "0.9.2"]]
+
+  :eastwood {:ignored-faults {:reflection {puppetlabs.trapperkeeper.logging [{:line 92}]
+                                           puppetlabs.trapperkeeper.internal [{:line 128}]
+                                           puppetlabs.trapperkeeper.testutils.logging true
+                                           puppetlabs.trapperkeeper.testutils.logging-test true
+                                           puppetlabs.trapperkeeper.services.nrepl.nrepl-service-test true
+                                           puppetlabs.trapperkeeper.plugins-test true}
+                              :local-shadows-var {puppetlabs.trapperkeeper.config-test true
+                                                  puppetlabs.trapperkeeper.services-test true
+                                                  java-service-example.java-service true
+                                                  puppetlabs.trapperkeeper.optional-deps-test true}
+                              :deprecations {puppetlabs.trapperkeeper.testutils.logging true
+                                             puppetlabs.trapperkeeper.testutils.logging-test true
+                                             puppetlabs.trapperkeeper.logging-test true}
+                              :def-in-def {puppetlabs.trapperkeeper.optional-deps-test true}}
+
+             :continue-on-exception true}
+
+  :main puppetlabs.trapperkeeper.main)
 
-  :main puppetlabs.trapperkeeper.main
-  )
