@@ -2,17 +2,14 @@
   (:require [cheshire.factory :refer [*json-factory*]]
             [clojure.java.jdbc :as sql]
             [clojure.tools.logging :as log]
-            [honeysql.core :as hcore]
-            [honeysql.format :as hfmt]
             [clojure.string :as str]
+            [puppetlabs.i18n.core :refer [trs tru]]
             [puppetlabs.puppetdb.cheshire :as json]
-            [puppetlabs.puppetdb.honeysql :as h]
+            [puppetlabs.puppetdb.honeysql]
             [puppetlabs.puppetdb.jdbc :as jdbc]
             [puppetlabs.puppetdb.schema :as pls]
-            [puppetlabs.puppetdb.utils :as utils]
             [puppetlabs.kitchensink.core :as kitchensink]
-            [schema.core :as s]
-            [puppetlabs.i18n.core :refer [trs]])
+            [schema.core :as s])
   (:import [java.sql Connection]
            [java.util UUID]
            [org.postgresql.util PGobject]))
@@ -25,6 +22,19 @@
                   col-type
                   (into-array java-type values)))
 
+(defn ast-path->array-path
+  "Converts integers in path to strings so that the result is suitable
+  for a text[]."
+  [path]
+  (mapv #(cond
+           (string? %) %
+           (int? %) (str %)
+           :else
+           (throw (IllegalArgumentException.
+                   (tru "Path array element wasn't string or integer in {0}"
+                        (pr-str path)))))
+        path))
+
 (def pg-extension-map
   "Maps to the table definition in postgres, but only includes some of the
    columns:
@@ -39,21 +49,12 @@
    :relocatable s/Bool
    :version (s/maybe s/Str)})
 
-(def db-version
-  "A list containing a major and minor version for the database"
-  [s/Int])
-
-;; FUNCTIONS
-(defn db-metadata-fn
-  []
+(defn db-metadata []
   (let [db-metadata (.getMetaData ^Connection (:connection (jdbc/db)))]
     {:database (.getDatabaseProductName db-metadata)
      :version [(.getDatabaseMajorVersion db-metadata)
                (.getDatabaseMinorVersion db-metadata)]}))
 
-(def db-metadata
-  (delay (db-metadata-fn)))
-
 (defn sql-current-connection-table-names
   "Returns the names of all of the tables in the public schema of the
   current connection's database.  This is most useful for debugging /
@@ -85,6 +86,31 @@
                    "INNER JOIN pg_namespace pn ON (pp.pronamespace = pn.oid) "
                    "INNER JOIN pg_language pl ON (pp.prolang = pl.oid) "
                    "WHERE pl.lanname NOT IN ('c') "
+                   (if (> 11 (-> (db-metadata) :version first))
+                     ;; proisagg boolean was replaced with prokind char in pg11
+                     "AND pp.proisagg = 'f'"
+                     "AND pp.prokind = 'f'")
+                   "AND pn.nspname NOT LIKE 'pg_%'"
+                   "AND pn.nspname <> 'information_schema'")
+        results (jdbc/with-db-transaction [] (jdbc/query-to-vec query))]
+    (map (fn [{:keys [name args]}] (str name "(" args ")"))
+         results)))
+
+(defn sql-current-connection-aggregate-names
+  "Returns the names of all of the functions in the public schema of
+  the current connection's database.  This is most useful for
+  debugging / testing purposes to allow introspection on the
+  database.  (Some of our unit tests rely on this.)."
+  []
+  (let [query (str "SELECT pp.proname as name, pg_catalog.pg_get_function_arguments(pp.oid) as args "
+                   "FROM pg_proc pp "
+                   "INNER JOIN pg_namespace pn ON (pp.pronamespace = pn.oid) "
+                   "INNER JOIN pg_language pl ON (pp.prolang = pl.oid) "
+                   "WHERE pl.lanname NOT IN ('c') "
+                   (if (> 11 (-> (db-metadata) :version first))
+                     ;; proisagg boolean was replaced with prokind char in pg11
+                     "AND pp.proisagg = 't'"
+                     "AND pp.prokind = 'a'")
                    "AND pn.nspname NOT LIKE 'pg_%'"
                    "AND pn.nspname <> 'information_schema'")
         results (jdbc/with-db-transaction [] (jdbc/query-to-vec query))]
@@ -167,10 +193,10 @@
   "Returns the SQL for converting the given column to a number, or to
   NULL if it is not numeric."
   [column]
-  (hcore/raw (format (str "CASE WHEN %s~E'^\\\\d+$' THEN %s::bigint "
-                          "WHEN %s~E'^\\\\d+\\\\.\\\\d+$' THEN %s::float "
-                          "ELSE NULL END")
-                     column column column column)))
+  (format (str "CASE WHEN %s~E'^\\\\d+$' THEN %s::bigint "
+               "WHEN %s~E'^\\\\d+\\\\.\\\\d+$' THEN %s::float "
+               "ELSE NULL END")
+          column column column column))
 
 (defn sql-array-type-string
   "Returns the SQL to declare an array of the supplied base database
@@ -187,8 +213,110 @@
   The returned SQL fragment will contain *one* parameter placeholder,
   which must be supplied as the value to be matched."
   [column]
-  (hcore/raw
-   (format "ARRAY[?::text] <@ %s" (name column))))
+  [:raw (format "ARRAY[?::text] <@ %s" (name column))])
+
+(defn ast-path-type-sig
+  [path]
+  (->> path
+       (map #(cond
+               (string? %) \s
+               (int? %) \i
+               :else
+               (throw (IllegalArgumentException.
+                       (tru "Path array element wasn't string or integer in {0}"
+                            (pr-str path))))))
+       (apply str)))
+
+(defn ast-rx-path-type-pattern
+  [path]
+  (->> path
+       (map #(cond
+               ;; If the pattern is a string that represents an
+               ;; integer (e.g. "456") we require a string by setting
+               ;; the relevant signature component to "s".  If it's
+               ;; anything else (even something like "4[5]6" that will
+               ;; match an integer), we allow any type by placing the
+               ;; like operator's "_" (match any single char) syntax
+               ;; into the signature pattern.  This is all in support
+               ;; of the currently defined behavior of the ~> (regexp
+               ;; array match) operator.  (See ast.markdown for
+               ;; additional information.)
+               (string? %) (if (re-matches #"\d+" %) \s \_)
+               (int? %) \i
+               :else
+               (throw (IllegalArgumentException.
+                       (tru "Path array element wasn't string or integer in {0}"
+                            (pr-str path))))))
+       (apply str)))
+
+(defn path-array-col-matches-ast-path
+  [column sig-col path]
+  ;; (path = array['w', 'x', '0', '1', 'y'] and type = 'ssiss')
+  (let [column (name column)
+        sig-col (name sig-col)
+        sig (-> path ast-path-type-sig jdbc/single-quote)]
+    [:raw
+     (str "("
+          column " = " (jdbc/str-vec->array-literal path)
+          " and "
+          sig-col " = " sig
+          ")")]))
+
+(defn path-array-col-matches-any-ast-path
+  ;; ((path = array['w', 'x', '0', '1', 'y'] and type = 'ssiss')
+  ;;  or (path = array['a', 'b', 'c'] and type = 'sss')
+  ;;  or (path = array['w', '3', '11'] and type = 'sii'))
+  [column sig-col paths]
+  (let [column (name column)
+        arrays (map ast-path->array-path paths)
+        sigs (map ast-path-type-sig paths)
+        sig-col (name sig-col)]
+    [:raw
+     (str "("
+          (->> (map (fn [array sig]
+                      (str "("
+                           column " = " (jdbc/str-vec->array-literal array)
+                           " and "
+                           sig-col " = " (jdbc/single-quote sig)
+                           ")"))
+                    arrays sigs)
+               (str/join " or "))
+          ")")]))
+
+(defn path-array-col-matches-rx-vec
+  [column sig-col path-rx]
+  ;; Produces results like this:
+  ;; -- need case statement for guaranteed short-circuit...
+  ;; case when array_length(path) >= array_length(rx)
+  ;;   then type like 'sss_sis'
+  ;;        and path[3] ~ 'rx-3'
+  ;;        and path[2] ~ 'rx-2'
+  ;;        and path[1] ~ 'rx-1'
+  ;;   else false
+  ;; end
+  (let [column (name column)
+        sig-col (name sig-col)
+        sig (-> path-rx ast-rx-path-type-pattern jdbc/single-quote)
+        ast->db #(cond
+                   (string? %) %
+                   (int? %) (str %)
+                   :else
+                   (throw (IllegalArgumentException.
+                           (tru "Regex array element wasn't string or integer in {0}"
+                                (pr-str path-rx)))))
+        matches-target (fn [i rx]
+                         (format "\n       and %s[%d] ~ %s"
+                                 column
+                                 (inc i)
+                                 (-> rx ast->db jdbc/single-quote)))]
+    [:raw
+     (str "(case when array_length(" column ", 1) = " (count path-rx) "\n"
+          "   then " sig-col " like " sig
+          (apply str
+                 (->> (map-indexed matches-target path-rx)
+                      reverse)) "\n"
+          "   else false\n"
+          " end)")]))
 
 (defn sql-regexp-match
   "Returns db code for performing a regexp match."
@@ -197,32 +325,70 @@
    [(keyword "~") column "?"]
    [:is-not column nil]])
 
-(defn sql-regexp-array-match
+(defn sql-regexp-array-match-str
   "Returns SQL for performing a regexp match against the contents of
   an array. If any of the array's items match the supplied regexp,
   then that satisfies the match."
   [column]
-  (hcore/raw
-   (format "EXISTS(SELECT 1 FROM UNNEST(%s) WHERE UNNEST ~ ?)" (name column))))
+  (format "EXISTS(SELECT 1 FROM UNNEST(%s) WHERE UNNEST ~ ?)" (name column)))
+
+(defn sql-regexp-array-match-v2
+  "Returns SQL for performing a regexp match against the contents of
+  an array. If any of the array's items match the supplied regexp,
+  then that satisfies the match."
+  [column]
+  [:raw
+   (format "EXISTS(SELECT 1 FROM UNNEST(%s) WHERE UNNEST ~ ?)" (name column))])
+
+(defn sql-cast
+  [type]
+  (fn [column]
+    (if (= type :jsonb)
+      [[:to_jsonb (keyword column)]]
+      [[:cast column type]])))
+
+(defn jsonb-null?
+  "A predicate determining whether the json types of a jsonb column are null."
+  [column null?]
+  (let [op (if null? "=" "<>")]
+    [:raw (format "jsonb_typeof(%s) %s 'null'" (name column) op)]))
 
 (defn sql-in-array
+  [column value]
+   ;; assumes that value has already been converted a string array representation
+   [:= column [:any value]])
+
+(defn jsonb-path-binary-expression
+  "Produce a predicate that compares against nested value with op and checks the
+  existence of a (presumably) top-level value. The existence check is necessary
+  because -> is not indexable (with GIN) but ? is. Assumes a GIN index on the
+  column supplied."
+  [op column qmarks]
+  (if (= "~" (name op))
+    (let [path-elts (cons column qmarks)
+          path (apply str
+                      (str/join "->" (butlast path-elts))
+                      (when-let [x (last path-elts)] ["->>" x]))]
+      [:raw (str/join \space
+                      [(str "((" path ")") (name op) "(?#>>'{}')"
+                       "and" column "??" "?)"])])
+    (let [delimited-qmarks (str/join "->" qmarks)]
+      [:raw (str/join \space
+                      [(str "(" column "->" delimited-qmarks ")")
+                       (name op) "?"
+                       "and" column "??" "?"])])))
+
+(defn jsonb-scalar-cast
+  [typ]
+  (fn
+    [column]
+    [:raw (format "(%s#>>'{}')::%s" column typ)]))
+
+(defn jsonb-scalar-regex
+  "Produce a predicate that matches a regex against a scalar jsonb value "
   [column]
-  (hcore/raw
-   (format "%s = ANY(?)" (first (hfmt/format column)))))
-
-(defn json-contains
-  [field]
-  (hcore/raw (format "%s @> ?" field)))
-
-(defn jsonb-regex
-  "Produce a predicate that matches a regex against a nested value and checks
-   the existence of a (presumably) top-level value. The existence check is
-   necessary because -> is not indexable but ?? is. Assumes a GIN index on the
-   column supplied."
-  [column qmarks]
-  (let [delimited-qmarks (str/join "->" qmarks)]
-    (hcore/raw (format "(%s->%s)::text ~ ?::text and %s ?? ?"
-                       column delimited-qmarks column))))
+  ;; This gets the unwrapped json value as text
+  [:raw (format "(%s#>>'{}')::text ~ ?" column)])
 
 (defn db-serialize
   "Serialize `value` into a form appropriate for querying against a
@@ -251,12 +417,12 @@
 
 (defn vacuum-analyze
   [db]
-  (sql/with-db-connection [conn db]
+  (sql/with-db-connection [_conn db]
     (sql/execute! db ["vacuum analyze"] {:transaction? false})))
 
 (defn parse-db-hash
   [^PGobject db-hash]
-  (clojure.string/replace (.getValue db-hash) "\\x" ""))
+  (str/replace (.getValue db-hash) "\\x" ""))
 
 (defn parse-db-uuid
   [^UUID db-uuid]
@@ -301,45 +467,26 @@
 
 (defn db-up?
   [db-spec]
-  (utils/with-timeout 1000 false
-    (try
-      (jdbc/with-transacted-connection db-spec
-        (let [select-42 "SELECT (a - b) AS answer FROM (VALUES ((7 * 7), 7)) AS x(a, b)"
-              [{:keys [answer]}] (jdbc/query [select-42])]
-          (= answer 42)))
-      (catch Exception _
-        false))))
+  (let [f (future
+            (try
+              (jdbc/with-db-connection db-spec
+                (= 42
+                   (-> "SELECT (a - b) AS answer FROM (VALUES ((7 * 7), 7)) AS x(a, b)"
+                       jdbc/query
+                       first
+                       :answer)))
+              (catch Exception e
+                (log/debug e (trs "Query to check if the database is up failed"))
+                false)))
+        result (deref f 1000 ::timed-out)]
+     (if (= ::timed-out result)
+       (do
+         (log/debug (trs "Query to check if the database is up timed out"))
+         false)
+       result)))
 
 (defn analyze-small-tables
   [small-tables]
   (log/info (trs "Analyzing small tables"))
   (apply jdbc/do-commands-outside-txn
          (map #(str "analyze " %) small-tables)))
-
-(defn handle-quoted-path-segment
-  [v]
-  (loop [result []
-         [s & splits] v]
-    (let [s-len (count s)]
-      (if (and (str/ends-with? s "\"")
-               (not (= s-len 1))
-               (or (<= s-len 2) (not (= (nth s (- s-len 2)) \\))))
-        [(str/join "." (conj result s)) splits]
-        (recur (conj result s) splits)))))
-
-(defn dotted-query->path
-  [string]
-  (loop [[s & splits :as v] (str/split string #"\.")
-         result []]
-    (if (nil? s)
-      result
-      (let [s-len (count s)]
-        (if (and (str/starts-with? s "\"")
-                 (or (= s-len 1)
-                     (or (not (str/ends-with? s "\""))
-                         (and (str/ends-with? s "\"")
-                              (>= s-len 2)
-                              (= (nth s (- s-len 2)) \\)))))
-          (let [[x xs] (handle-quoted-path-segment v)]
-            (recur xs (conj result x)))
-          (recur splits (conj result s)))))))
